@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-use version; our $VERSION = version->declare("v0.4.1");
+use version; our $VERSION = version->declare("v0.4.2");
 
 use Data::Gimei::Name;
 use Data::Gimei::Address;
@@ -34,8 +34,10 @@ Data::Gimei - a Perl port of Ruby's gimei generates fake data in Japanese.
 
 =head1 SYNOPSIS
 
+  use 5.010;
+  use strict;
   use warnings;
-  use v5.22;
+
   binmode STDOUT, ":utf8";
 
   use Data::Gimei;
